'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _templateObject = _taggedTemplateLiteral(['{bold datree.io insights engine}'], ['{bold datree.io insights engine}']),
    _templateObject2 = _taggedTemplateLiteral(['{blue.bold https://app.datree.io/pkg/alternative-packages/', '}'], ['{blue.bold https://app.datree.io/pkg/alternative-packages/', '}']),
    _templateObject3 = _taggedTemplateLiteral(['{blue.bold https://app.datree.io/pkg/single-package/', '}'], ['{blue.bold https://app.datree.io/pkg/single-package/', '}']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var Table = require('cli-table');
var chalk = require('chalk');
var score = require('./score');

var SOURCE_PACKAGE_TYPE = 'sourcePackage';
var ALTERNATIVE_PACKAGE_TYPE = 'alternativePackage';
var PACKAGE_DISPLAY_HEADERS = ['Package Name', 'Version', 'License', 'Description', 'My Usage', 'Score'];
var VERSION_DISPLAY_HEADERS = ['Package Name', 'package.json Version', 'Latest Version', 'Description'];

var Renderer = function () {
  function Renderer(_ref) {
    var _this = this;

    var logger = _ref.logger;

    _classCallCheck(this, Renderer);

    this.queue = [];
    this.logger = logger;
    this.shouldRender = true;
    // Print out table queue on process exit
    process.on('exit', function () {
      return _this.render();
    });
  }

  _createClass(Renderer, [{
    key: 'render',
    value: function render() {
      this.logger.info(this.queue.length);
      if (this.shouldRender) {
        var _iteratorNormalCompletion = true;
        var _didIteratorError = false;
        var _iteratorError = undefined;

        try {
          for (var _iterator = this.queue[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
            var item = _step.value;
            console.log(item);
          }
        } catch (err) {
          _didIteratorError = true;
          _iteratorError = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion && _iterator.return) {
              _iterator.return();
            }
          } finally {
            if (_didIteratorError) {
              throw _iteratorError;
            }
          }
        }
      }
    }
  }, {
    key: 'trimStringToLength',
    value: function trimStringToLength(str, len) {
      if (str) {
        if (str.length <= len) return str;
        return str.substring(0, len) + '...';
      }
    }
  }, {
    key: 'boolToString',
    value: function boolToString(bool) {
      if (bool) return 'Yes';else return 'No';
    }
  }, {
    key: 'fractionToPercentageString',
    value: function fractionToPercentageString(fraction) {
      var val = Math.round(fraction * 100);
      if (!isNaN(val)) return val.toFixed() + ' %';
      return '';
    }
  }, {
    key: 'createSeparatorRow',
    value: function createSeparatorRow(len) {
      return Array(len).fill('');
    }
  }, {
    key: 'createTableWithHeders',
    value: function createTableWithHeders(head) {
      return new Table({
        head: head,
        chars: { mid: '', 'left-mid': '', 'mid-mid': '', 'right-mid': '' },
        style: { head: ['bold', 'underline'] }
      });
    }
  }, {
    key: 'createPackageRow',
    value: function createPackageRow(data, type, hasHigherScore) {
      var style = chalk;
      if (type === SOURCE_PACKAGE_TYPE) style = style.bold;
      if (data.quality.deprecated) style = style.red;
      var dataSet = ['' + style(data.name || ''), '' + style(data.version || 'No Insight'), '' + style(this.trimStringToLength(data.license, 4) || ''), '' + style(this.trimStringToLength(data.description, 20) || '')];

      if (data.internalUsage) dataSet.push('' + style(this.fractionToPercentageString(data.internalUsage.usage) || 'No Insight'));
      if (hasHigherScore) style = style.bold.green;
      dataSet.push('' + style(Number(data.calculatedScore) || ''));
      return dataSet;
    }
  }, {
    key: 'createVersionRow',
    value: function createVersionRow(data) {
      var style = chalk;
      if (data && data.quality && data.quality.deprecated) style = style.red;

      return ['' + style(data.name || ''), '' + style(data.pkgJsonVersion || ''), '' + style(data.version), '' + style(this.trimStringToLength(data.description, 20) || '')];
    }
  }, {
    key: 'getScore',
    value: function getScore(pkgData, weights) {
      var calculatedScore = void 0;
      if (Object.keys(weights).length > 0) calculatedScore = score.calculatePackageScore(pkgData, weights, true);else calculatedScore = pkgData.score.final;
      return (Number(calculatedScore) * 100).toFixed();
    }
  }, {
    key: 'renderPackagesTable',
    value: function renderPackagesTable(_ref2) {
      var _this2 = this;

      var data = _ref2.data,
          weights = _ref2.weights;

      if (!data.some(function (pkgSet) {
        return pkgSet.alternatives;
      })) {
        this.shouldRender = false;
        return;
      }

      try {
        var _loop = function _loop(idx, pkgSet) {
          if (!('alternatives' in pkgSet)) return 'continue';
          var scores = {};
          scores[pkgSet.source.name] = _this2.getScore(pkgSet.source, weights);
          pkgSet.source.calculatedScore = scores[pkgSet.source.name];

          var _iteratorNormalCompletion3 = true;
          var _didIteratorError3 = false;
          var _iteratorError3 = undefined;

          try {
            for (var _iterator3 = pkgSet.alternatives[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
              var alternative = _step3.value;

              scores[alternative.name] = _this2.getScore(alternative, weights);
              alternative.calculatedScore = scores[alternative.name];
            }
          } catch (err) {
            _didIteratorError3 = true;
            _iteratorError3 = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion3 && _iterator3.return) {
                _iterator3.return();
              }
            } finally {
              if (_didIteratorError3) {
                throw _iteratorError3;
              }
            }
          }

          var highestScorePackageName = Object.keys(scores).sort(function (a, b) {
            return scores[b] - scores[a];
          })[0];
          _this2.logger.info(highestScorePackageName);
          _this2.queue.push('Alternative Packages for ' + chalk.bold.cyan(pkgSet.source.name));
          var table = _this2.createTableWithHeders(PACKAGE_DISPLAY_HEADERS);

          if (idx < data.length) table.push(_this2.createSeparatorRow(PACKAGE_DISPLAY_HEADERS.length));
          table.push(_this2.createPackageRow(pkgSet.source, SOURCE_PACKAGE_TYPE, pkgSet.source.name === highestScorePackageName));
          pkgSet.alternatives = pkgSet.alternatives.sort(function (a, b) {
            return b.calculatedScore - a.calculatedScore;
          });

          var _iteratorNormalCompletion4 = true;
          var _didIteratorError4 = false;
          var _iteratorError4 = undefined;

          try {
            for (var _iterator4 = pkgSet.alternatives[Symbol.iterator](), _step4; !(_iteratorNormalCompletion4 = (_step4 = _iterator4.next()).done); _iteratorNormalCompletion4 = true) {
              var _alternative = _step4.value;

              table.push(_this2.createPackageRow(_alternative, ALTERNATIVE_PACKAGE_TYPE, _alternative.name === highestScorePackageName));
            }
          } catch (err) {
            _didIteratorError4 = true;
            _iteratorError4 = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion4 && _iterator4.return) {
                _iterator4.return();
              }
            } finally {
              if (_didIteratorError4) {
                throw _iteratorError4;
              }
            }
          }

          _this2.logger.info({ table: table });
          _this2.queue.push(table.toString());
          _this2.renderLink('alternative', pkgSet);
          _this2.renderSeparator();
        };

        var _iteratorNormalCompletion2 = true;
        var _didIteratorError2 = false;
        var _iteratorError2 = undefined;

        try {
          for (var _iterator2 = data.entries()[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
            var _ref3 = _step2.value;

            var _ref4 = _slicedToArray(_ref3, 2);

            var idx = _ref4[0];
            var pkgSet = _ref4[1];

            var _ret = _loop(idx, pkgSet);

            if (_ret === 'continue') continue;
          }
        } catch (err) {
          _didIteratorError2 = true;
          _iteratorError2 = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion2 && _iterator2.return) {
              _iterator2.return();
            }
          } finally {
            if (_didIteratorError2) {
              throw _iteratorError2;
            }
          }
        }
      } catch (err) {
        this.logger.error(err);
        throw err;
      }
    }
  }, {
    key: 'renderVersionsTable',
    value: function renderVersionsTable(_ref5) {
      var data = _ref5.data;

      try {
        this.queue.push('Version Summary');
        var _table = this.createTableWithHeders(VERSION_DISPLAY_HEADERS);
        var _iteratorNormalCompletion5 = true;
        var _didIteratorError5 = false;
        var _iteratorError5 = undefined;

        try {
          for (var _iterator5 = data[Symbol.iterator](), _step5; !(_iteratorNormalCompletion5 = (_step5 = _iterator5.next()).done); _iteratorNormalCompletion5 = true) {
            var pkgSet = _step5.value;

            _table.push(this.createVersionRow(pkgSet.source));
          }
        } catch (err) {
          _didIteratorError5 = true;
          _iteratorError5 = err;
        } finally {
          try {
            if (!_iteratorNormalCompletion5 && _iterator5.return) {
              _iterator5.return();
            }
          } finally {
            if (_didIteratorError5) {
              throw _iteratorError5;
            }
          }
        }

        this.logger.info({ table: _table });
        this.queue.push(_table.toString());
        this.renderLink('single', data);
      } catch (err) {
        this.logger.error(err);
        throw err;
      }
    }
  }, {
    key: 'renderLogo',
    value: function renderLogo() {
      this.queue.push(chalk(_templateObject));
    }
  }, {
    key: 'renderSeparator',
    value: function renderSeparator() {
      this.queue.push('');
    }
  }, {
    key: 'renderLegend',
    value: function renderLegend(packageList) {
      if (packageList.some(function (pkg) {
        return pkg && pkg.source && pkg.source.quality && pkg.source.quality.deprecated;
      })) this.queue.push(chalk.bgRed.bold('  ') + ' - ' + chalk('Package is deprecated'));
    }
  }, {
    key: 'renderLink',
    value: function renderLink(linkType, data) {
      var link = void 0;
      if (linkType === 'single') link = this._renderSinglePackageLinks(data);else if (linkType === 'alternative') this._renderAlternativesLinks(data);
    }
  }, {
    key: '_renderAlternativesLinks',
    value: function _renderAlternativesLinks(pkgSet) {
      var packages = [pkgSet.source.name];
      if (pkgSet.alternatives && pkgSet.alternatives.length > 0) {
        packages = packages.concat(pkgSet.alternatives.map(function (alt) {
          return alt.name;
        }));
        this.queue.push(chalk(_templateObject2, packages.join(',')));
      }
    }
  }, {
    key: '_renderSinglePackageLinks',
    value: function _renderSinglePackageLinks(packageList) {
      var _iteratorNormalCompletion6 = true;
      var _didIteratorError6 = false;
      var _iteratorError6 = undefined;

      try {
        for (var _iterator6 = packageList[Symbol.iterator](), _step6; !(_iteratorNormalCompletion6 = (_step6 = _iterator6.next()).done); _iteratorNormalCompletion6 = true) {
          var pkg = _step6.value;

          if (pkg && pkg.source && pkg.source.quality && pkg.source.quality.deprecated) this.queue.push(chalk(_templateObject3, pkg.source.name));
        }
      } catch (err) {
        _didIteratorError6 = true;
        _iteratorError6 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion6 && _iterator6.return) {
            _iterator6.return();
          }
        } finally {
          if (_didIteratorError6) {
            throw _iteratorError6;
          }
        }
      }
    }
  }]);

  return Renderer;
}();

module.exports = Renderer;
//# sourceMappingURL=cli-renderer.js.map