'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

require('babel-polyfill');

var request = require('request-promise-native');
var program = require('commander');
var auth = require('../lib/auth');
var weights = require('../lib/weights');
var loggerFactory = require('./loggerFactory');
var utils = require('./utils');

var logger = loggerFactory.get('insight');
var BASE_URL = 'https://gateway.datree.io';

program.option('-e, --event <event>', 'Event type').option('-d, --data <data>', 'The payload').parse(process.argv);

var makeRequest = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(_ref) {
    var uri = _ref.uri,
        data = _ref.data,
        token = _ref.token;
    var headers, options;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            headers = {
              'x-datree-sdk-type': 'nodejs',
              'x-datree-sdk-version': utils.getVersion()
            };
            options = {
              headers: headers,
              uri: uri,
              body: data,
              json: true
            };

            if (token) options.headers.Authorization = 'Bearer ' + token;
            return _context.abrupt('return', request.post(options));

          case 4:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function makeRequest(_x) {
    return _ref2.apply(this, arguments);
  };
}();

var notifyUnInstall = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(data, token) {
    var uri;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            uri = BASE_URL + '/cli/uninstall';
            _context2.prev = 1;
            _context2.next = 4;
            return makeRequest({ uri: uri, data: data, token: token });

          case 4:
            _context2.next = 9;
            break;

          case 6:
            _context2.prev = 6;
            _context2.t0 = _context2['catch'](1);

            logger.error(_context2.t0);

          case 9:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this, [[1, 6]]);
  }));

  return function notifyUnInstall(_x2, _x3) {
    return _ref3.apply(this, arguments);
  };
}();
var notifyInstall = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(data, token) {
    var uri;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            uri = BASE_URL + '/cli/install';
            _context3.prev = 1;
            _context3.next = 4;
            return makeRequest({ uri: uri, data: data, token: token });

          case 4:
            _context3.next = 9;
            break;

          case 6:
            _context3.prev = 6;
            _context3.t0 = _context3['catch'](1);

            logger.error(_context3.t0);

          case 9:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this, [[1, 6]]);
  }));

  return function notifyInstall(_x4, _x5) {
    return _ref4.apply(this, arguments);
  };
}();

var getInsights = function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(data, token) {
    var uri, res;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            uri = BASE_URL + '/packages/javascript';
            _context4.prev = 1;
            _context4.next = 4;
            return makeRequest({ uri: uri, data: data, token: token });

          case 4:
            res = _context4.sent;
            return _context4.abrupt('return', res);

          case 8:
            _context4.prev = 8;
            _context4.t0 = _context4['catch'](1);

            logger.error(_context4.t0);
            return _context4.abrupt('return', []);

          case 12:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, this, [[1, 8]]);
  }));

  return function getInsights(_x6, _x7) {
    return _ref5.apply(this, arguments);
  };
}();

var main = function () {
  var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5() {
    var token, data, insight, userWeights, res;
    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            token = auth.getToken();
            data = JSON.parse(program.data);
            _context5.t0 = program.event;
            _context5.next = _context5.t0 === 'install' ? 5 : _context5.t0 === 'uninstall' ? 8 : _context5.t0 === 'insight' ? 11 : 20;
            break;

          case 5:
            _context5.next = 7;
            return notifyInstall(data, token);

          case 7:
            return _context5.abrupt('break', 21);

          case 8:
            _context5.next = 10;
            return notifyUnInstall(data, token);

          case 10:
            return _context5.abrupt('break', 21);

          case 11:
            _context5.next = 13;
            return getInsights(data, token);

          case 13:
            insight = _context5.sent;
            _context5.next = 16;
            return weights.getWeights(token);

          case 16:
            userWeights = _context5.sent;
            res = JSON.stringify({ insight: insight, userWeights: userWeights });

            process.stdout.write(res);
            return _context5.abrupt('break', 21);

          case 20:
            logger.error('Unknown event ' + program.event);

          case 21:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, this);
  }));

  return function main() {
    return _ref6.apply(this, arguments);
  };
}();

if (require.main === module) {
  main().then(function (_) {
    process.exitCode = 0;
  }).catch(function (err) {
    logger.error(err);
    process.exitCode = 1;
  });
} else {
  module.exports = {
    getInsights: getInsights,
    notifyInstall: notifyInstall,
    notifyUnInstall: notifyUnInstall
  };
}
//# sourceMappingURL=insight.js.map