'use strict';

var fs = require('fs');
var childProcess = require('child_process');
var path = require('path');
var os = require('os');
var ini = require('ini');
var utils = require('../lib/utils');
var loggerFactory = require('./loggerFactory');
var logger = void 0;

function enableHook(hookFullPath, homeDir) {
  var npmrc = path.join(homeDir, '.npmrc');
  var config = {};
  if (fs.existsSync(npmrc)) config = ini.parse(fs.readFileSync(npmrc).toString());

  config['onload-script'] = '' + hookFullPath;
  fs.writeFileSync(npmrc, ini.stringify(config));
}

function hookSetup() {
  var homeDir = os.homedir();
  var datreeioDir = utils.getDatreeioDir();

  try {
    fs.mkdirSync(datreeioDir);
  } catch (err) {}

  logger = loggerFactory.get('install');
  try {
    var hookFullPath = datreeioDir + '/hook.js';

    var hookData = fs.readFileSync(path.join(__dirname, 'hook.js'));
    fs.writeFileSync(hookFullPath, hookData);
    enableHook(hookFullPath, homeDir);
    var data = {
      systeminfo: utils.getSystemInfo()
    };

    utils.setVersion();

    var insightsProcess = childProcess.spawnSync('node', [__dirname + '/insight.js', '-e', 'install', '-d', '' + JSON.stringify(data)]);
  } catch (err) {
    logger.error(err);
  }
}

hookSetup();

module.exports = {
  hookSetup: hookSetup
};
//# sourceMappingURL=install.js.map