'use strict';

var main = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var argv, argumentsExtractor, info, data, insightsProcess, insightsResponse, insight, renderer, installType;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            try {
              logger.info('# datree.io initializing cli integration...');
              // Parse argv
              argv = process.argv.slice(2);
              argumentsExtractor = new args.ArgumentsExtractor(argv.slice(1));
              // Fetch package.json info (if exists)

              info = node.extractPackageInfo(process.env.PWD);
              // Fetch system information

              info.systeminfo = utils.getSystemInfo();
              // Assign npm action
              info.action = argv[0];
              // Assign argv
              info.argv = process.argv;
              // Get full action
              info.full_action = [info.action].concat(argumentsExtractor.extractActionArgs());

              // If in npm install - parse installed packages
              if (info.action === 'install' || info.action === 'i') {
                info.installaction = argumentsExtractor.extractPackagesArgv();

                // fetch insights
                data = JSON.stringify(info);
                insightsProcess = childProcess.spawnSync('node', [__dirname + '/insight.js', '-e', 'insight', '-d', '' + data]);
                insightsResponse = JSON.parse(insightsProcess.stdout.toString('utf8'));
                insight = insightsResponse.insight;


                if (insight && insight.length > 0) {
                  renderer = new Renderer({ logger: logger });

                  renderer.renderSeparator();
                  renderer.renderLogo();
                  renderer.renderLegend(insight);
                  renderer.renderSeparator();
                  installType = void 0;

                  if (info.installaction.length > 0) {
                    installType = 'alternative';
                    renderer.renderPackagesTable({
                      data: insight,
                      weights: insightsResponse.userWeights
                    });
                  } else {
                    installType = 'single';
                    insight.forEach(function (pkgSet) {
                      var pkgJsonVersion = node.getVersionFromDependencies(info.packages, pkgSet.source.name);
                      pkgSet.source.pkgJsonVersion = pkgJsonVersion;
                    });
                    renderer.renderVersionsTable({
                      data: insight
                    });
                  }

                  if (utils.isCI()) utils.writeToFile('test.log', insight);
                }
              }
            } catch (err) {
              logger.error(err);
            }

          case 1:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function main() {
    return _ref.apply(this, arguments);
  };
}();

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var Renderer = require('./cli-renderer');
var args = require('./argumentsExtractor');
var node = require('./node');
var utils = require('./utils');
var childProcess = require('child_process');

var loggerFactory = require('./loggerFactory');
var logger = loggerFactory.get('main');

module.exports = {
  main: main
};
//# sourceMappingURL=main.js.map