'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var fs = require('fs');
var path = require('path');

var NODEJS_PACKAGE_FILENAME = 'package.json';
var DEP_TYPES = ['dependencies', 'devDependencies', 'bundledDependencies', 'peerDependencies', 'optionalDependencies'];
function getVersionFromDependencies(packages, packageName) {
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = DEP_TYPES[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var depType = _step.value;

      if (packages[depType]) {
        var pkg = Object.keys(packages[depType]).find(function (pkg) {
          return pkg === packageName;
        });
        if (pkg) return packages[depType][pkg];
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }
}
/**
 * Extracts packages from the Node.js package.json file
 * @param {String} packageJson - The Node.js repo location
 */
function getPackages(packageJson) {
  var packages = {};

  var _iteratorNormalCompletion2 = true;
  var _didIteratorError2 = false;
  var _iteratorError2 = undefined;

  try {
    for (var _iterator2 = Object.keys(packageJson)[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
      var deps = _step2.value;

      if (DEP_TYPES.includes(deps)) {
        packages[deps] = packageJson[deps];
      }
    }
  } catch (err) {
    _didIteratorError2 = true;
    _iteratorError2 = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion2 && _iterator2.return) {
        _iterator2.return();
      }
    } finally {
      if (_didIteratorError2) {
        throw _iteratorError2;
      }
    }
  }

  return packages;
}

function packageJsonExists(repoDir) {
  if (!fs.existsSync(repoDir + '/' + NODEJS_PACKAGE_FILENAME)) {
    throw new Error('Package file: ' + NODEJS_PACKAGE_FILENAME + ' not found in: ' + repoDir);
  }
}

function readPackageJson(repoDir) {
  return JSON.parse(fs.readFileSync(repoDir + '/' + NODEJS_PACKAGE_FILENAME).toString('utf8'));
}

function extractPackageInfo(repoDir) {
  var packageData = {};
  try {
    packageJsonExists(repoDir);
  } catch (err) {
    return packageData;
  }

  var packageJson = readPackageJson(repoDir);
  var packages = getPackages(packageJson);
  var repositoryName = extractRepositoryName(packageJson.repository);

  packageData = {
    project_name: extractProjectName(packageJson.name, repoDir),
    node_package_index: packageJson,
    repo_name: repositoryName,
    package_index_path: path.join(repoDir, NODEJS_PACKAGE_FILENAME),
    packages: packages
  };
  return packageData;
}

function extractProjectName(packageJsonName, repoDir) {
  return packageJsonName || path.basename(repoDir);
}

function extractRepositoryName(repository) {
  var repositoryName = '';
  if (typeof repository === 'string') {
    var repositoryMatch = repository.match(/(?:\/)+(\w*)[^#]*/);
    if (repositoryMatch) repositoryName = repositoryMatch[1];else repositoryName = repository;
  } else if ((typeof repository === 'undefined' ? 'undefined' : _typeof(repository)) === 'object') {
    var repositoryUrlParts = void 0;

    switch (repository.type) {
      case 'git':
        repositoryUrlParts = repository.url.split('/');
        repositoryUrlParts = repositoryUrlParts[repositoryUrlParts.length - 1];
        repositoryName = repositoryUrlParts.split('.')[0];
        break;
      case 'svn':
        repositoryUrlParts = repository.url.split('/');
        repositoryName = repositoryUrlParts[repositoryUrlParts.length - 1];
        break;
      default:
        repositoryName = '';
    }
  }
  return repositoryName;
}

module.exports = {
  getPackages: getPackages,
  packageJsonExists: packageJsonExists,
  readPackageJson: readPackageJson,
  extractPackageInfo: extractPackageInfo,
  getVersionFromDependencies: getVersionFromDependencies,
  NODEJS_PACKAGE_FILENAME: NODEJS_PACKAGE_FILENAME
};
//# sourceMappingURL=node.js.map