'use strict';

var fs = require('fs');
var childProcess = require('child_process');
var ini = require('ini');
var path = require('path');
var os = require('os');
var utils = require('../lib/utils');
var loggerFactory = require('./loggerFactory');
var logger = loggerFactory.get('uninstall');

function disableHook(homeDir) {
  var npmrc = path.join(homeDir, '.npmrc');
  var config = ini.parse(fs.readFileSync(npmrc).toString());
  config['onload-script'] = '';
  fs.writeFileSync(npmrc, ini.stringify(config));
}

function uninstall() {
  try {
    var homeDir = os.homedir();
    disableHook(homeDir);
    var data = {
      systeminfo: utils.getSystemInfo(),
      installDate: utils.getInstallDate()
    };
    var insightsProcess = childProcess.spawnSync('node', [__dirname + '/insight.js', '-e', 'uninstall', '-d', '' + JSON.stringify(data)]);
    console.log(insightsProcess.stdout.toString('utf8'));
  } catch (err) {
    logger.error(err);
  }
}

uninstall();

module.exports = {
  uninstall: uninstall
};
//# sourceMappingURL=uninstall.js.map