'use strict';

var os = require('os');
var path = require('path');
var osName = require('os-name');
var fs = require('fs');
var pkgJson = require('../package.json');

function isDebug() {
  return process.env.DATREE_ENV && process.env.DATREE_ENV !== 'ci';
}

function isCI() {
  return process.env.DATREE_ENV && process.env.DATREE_ENV === 'ci';
}

function getSystemInfo() {
  return {
    date_time: new Date().toISOString(),
    lang: 'nodejs',
    lang_version: process.version,
    os_platform: os.platform(),
    os_release: os.release(),
    os_name: osName(),
    node_components: process.versions
  };
}
function setVersion() {
  var versionPath = path.join(getDatreeioDir(), 'VERSION');
  var version = pkgJson.version;
  fs.writeFileSync(versionPath, version);
}
function getVersion() {
  var versionPath = path.join(getDatreeioDir(), 'VERSION');
  return fs.readFileSync(versionPath).toString('utf8').replace(/\n$/, '');
}

function getDatreeioDir() {
  var homeDir = os.homedir();
  return path.join(homeDir, '.datreeio');
}

function writeToFile(fileName, data) {
  var fileLocation = path.join(getDatreeioDir(), fileName);
  fs.writeFileSync(fileLocation, JSON.stringify(data));
}

function getInstallDate() {
  var datreeioDir = getDatreeioDir();
  var stats = fs.statSync(datreeioDir);
  return stats.birthtime;
}

module.exports = {
  getSystemInfo: getSystemInfo,
  getDatreeioDir: getDatreeioDir,
  writeToFile: writeToFile,
  getInstallDate: getInstallDate,
  getVersion: getVersion,
  setVersion: setVersion,
  isDebug: isDebug,
  isCI: isCI
};
//# sourceMappingURL=utils.js.map